.. change::
    :tags: bug, sql
    :tickets: 9075
    :versions: 2.0.0rc3

    Fixed bug / regression where using :func:`.bindparam()` with the same name
    as a column in the :meth:`.Update.values` method of :class:`.Update`, as
    well as the :meth:`_sql.Insert.values` method of :class:`_sql.Insert` in
    2.0 only, would in some cases silently fail to honor the SQL expression in
    which the parameter were presented, replacing the expression with a new
    parameter of the same name and discarding any other elements of the SQL
    expression, such as SQL functions, etc. The specific case would be
    statements that were constructed against ORM entities rather than plain
    :class:`.Table` instances, but would occur if the statement were invoked
    with a :class:`.Session` or a :class:`.Connection`.

    :class:`.Update` part of the issue was present in both 2.0 and 1.4 and is
    backported to 1.4.
